pub enum SendToError {
NotWriteable,
CreateSock(IpSockCreationError),
Send(IpSockSendError),
Zone(ZonedAddressError),
RemotePortUnset,
RemoteUnexpectedlyMapped,
RemoteUnexpectedlyNonMapped,
SendBufferFull,
InvalidLength,
}Expand description
An error encountered while sending a UDP packet to an alternate address.
Variants
NotWriteable
The socket is not writeable.
CreateSock(IpSockCreationError)
An error was encountered while trying to create a temporary IP socket to use for the send operation.
Send(IpSockSendError)
An error was encountered while trying to send via the temporary IP socket.
Zone(ZonedAddressError)
There was a problem with the remote address relating to its zone.
RemotePortUnset
Disallow sending packets with a remote port of 0. See
UdpRemotePort::Unset for the rationale.
RemoteUnexpectedlyMapped
The remote address is mapped (i.e. an ipv4-mapped-ipv6 address), but the socket is not dual-stack enabled.
RemoteUnexpectedlyNonMapped
The remote address is non-mapped (i.e not an ipv4-mapped-ipv6 address), but the socket is dual stack enabled and bound to a mapped address.
SendBufferFull
The socket’s send buffer is full.
InvalidLength
Invalid message length.